/**
 * Copyright (c) 2006-2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.objectweb.petals.tools.rmi.client;

import java.net.MalformedURLException;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import org.objectweb.petals.tools.rmi.remote.RemoteComponentContextClientFactory;

/**
 * Get an instance of RMI Component context factory to create a component context per RMI client.
 * 
 * @author Nicolas Salatge - EBM WebSourcing
 * @author Christophe DENEUX - Linagora
 */
public final class ComponentContexFactoryLocator {

    /**
     * The registry itself.
     */
    private static java.rmi.registry.Registry registry;

    /**
     * the RMI component context factory.
     */
    private RemoteComponentContextClientFactory rmiCcFactory = null;

    /**
     * the default constructor.
     * 
     * @param rmiHost
     *            the ip address of the rmi host (if null, the localhost is contacted)
     * @param rmiPort
     *            the rmi port
     * @param rmiComponentContextName
     *            the rmi component context factory name
     * @throws MalformedURLException
     *             impossible to realized a remote access
     * @throws RemoteException
     *             impossible to realized a remote access
     * @throws NotBoundException
     *             impossible to realized a remote access
     */
    public ComponentContexFactoryLocator(final String rmiHost, final int rmiPort,
            final String rmiComponentContextName)
    throws MalformedURLException, RemoteException, NotBoundException {

        ComponentContexFactoryLocator.registry = java.rmi.registry.
        LocateRegistry.getRegistry(rmiHost, rmiPort);

        this.rmiCcFactory = (RemoteComponentContextClientFactory) ComponentContexFactoryLocator.registry
                .lookup(rmiComponentContextName);
    }

    /**
     * Get an instance of RMI Component context factory.
     * 
     * @return the instance of RMI Component context factory.
     */
    public RemoteComponentContextClientFactory getComponentClientContextFactory() {
        return this.rmiCcFactory;
    }

}
